bluetooth_mesh.models
==============

.. autoclass:: bluetooth_mesh.models.Model
   :members:
   :undoc-members:


Foundation Models
-----------------

.. autoclass:: bluetooth_mesh.models.ConfigServer
   :members:

.. autoclass:: bluetooth_mesh.models.ConfigClient
   :members:

.. autoclass:: bluetooth_mesh.models.HealthServer
   :members:

.. autoclass:: bluetooth_mesh.models.HealthClient
   :members:


Generic Models
--------------

.. autoclass:: bluetooth_mesh.models.GenericOnOffServer
   :members:

.. autoclass:: bluetooth_mesh.models.GenericOnOffClient
   :members:


Silvair Vendor Models
---------------------

.. autoclass:: bluetooth_mesh.models.DebugClient
   :members:

.. autoclass:: bluetooth_mesh.models.NetworkDiagnosticClient
   :members:

.. autoclass:: bluetooth_mesh.models.NetworkDiagnosticSetupClient
   :members:
